@@ -120,7 +120,7 @@ def interview():
 
     while True:
         lang = input(f"Enter either {Fore.CYAN}python{Fore.RESET}, {Fore.CYAN}javascript{Fore.RESET}, or "
-                     f"{Fore.CYAN}c++{Fore.RESET} for your desired language").lower()
+                     f"{Fore.CYAN}c++{Fore.RESET} for your desired language: ").lower()
         if lang == "python" or lang == "javascript" or lang == "c++":
             break
         else:
